==> developer-center-api-3.6.71-sources.jar: cn/com/duiba/developer/center/api/domain/param/EmployeeParam.java <==
package cn.com.duiba.developer.center.api.domain.param;

import java.io.Serializable;
import java.util.List;

/**
 * @author zyj
 * @date 2018/10/10
 */
public class EmployeeParam implements Serializable {
    private static final long serialVersionUID = 4072064149592504522L;

    /**
     * appId
     */
    private Long appId;
    /**
     * developerId
     */
    private Long developerId;
    /**
     * 开发者账号
     */
    private String developerAccount;
    /**
     * 员工昵称
     */
    private String nickName;
    /**
     * 角色id
     */
    private Long roleId;
    /**
     * 角色名称
     */
    private String roleName;

    /**
     * 开发者的ids集合
     */
    private List<Long> developerIds;

    public List<Long> getDeveloperIds() {
        return developerIds;
    }

    public void setDeveloperIds(List<Long> developerIds) {
        this.developerIds = developerIds;
    }

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public String getRoleName() {
        return roleName;
    }

    public void setRoleName(String roleName) {
        this.roleName = roleName;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getDeveloperAccount() {
        return developerAccount;
    }

    public void setDeveloperAccount(String developerAccount) {
        this.developerAccount = developerAccount;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public Long getRoleId() {
        return roleId;
    }

    public void setRoleId(Long roleId) {
        this.roleId = roleId;
    }
}

==> developer-center-api-3.11.10-20251204.083310-1-sources.jar: cn/com/duiba/developer/center/api/domain/param/EmployeeParam.java <==
package cn.com.duiba.developer.center.api.domain.param;

import java.io.Serializable;
import java.util.List;

/**
 * @author zyj
 * @date 2018/10/10
 */
public class EmployeeParam implements Serializable {
    private static final long serialVersionUID = 4072064149592504522L;

    /**
     * appId
     */
    private Long appId;
    /**
     * developerId
     */
    private Long developerId;
    /**
     * 开发者账号
     */
    private String developerAccount;
    /**
     * 员工昵称
     */
    private String nickName;
    /**
     * 角色id
     */
    private Long roleId;
    /**
     * 角色名称
     */
    private String roleName;

    /**
     * 开发者的ids集合
     */
    private List<Long> developerIds;

    /**
     * 开发者供应商id
     */
    private Long developerBindSupplierId;

    public List<Long> getDeveloperIds() {
        return developerIds;
    }

    public void setDeveloperIds(List<Long> developerIds) {
        this.developerIds = developerIds;
    }

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public String getRoleName() {
        return roleName;
    }

    public void setRoleName(String roleName) {
        this.roleName = roleName;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getDeveloperAccount() {
        return developerAccount;
    }

    public void setDeveloperAccount(String developerAccount) {
        this.developerAccount = developerAccount;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public Long getRoleId() {
        return roleId;
    }

    public void setRoleId(Long roleId) {
        this.roleId = roleId;
    }

    public Long getDeveloperBindSupplierId() {
        return developerBindSupplierId;
    }

    public void setDeveloperBindSupplierId(Long developerBindSupplierId) {
        this.developerBindSupplierId = developerBindSupplierId;
    }
}
